@@ -4,60 +4,52 @@ use warnings;
 use strict;
 use POE::Component::IRC::Plugin qw(:ALL);
 
-
 sub new {
-	my $package = shift; 
-	my $args = shift;
-	my $self = {
-		threshold => 0.5, #Threshold to limit unnecessary wubs.
-		period    => 30,  #A time period to rate limit wubs.
-		last_wub  => 0,
-		max_wubs =>  20,  #maximum amount of wubs in one message
-		min_wubs =>  5,   #minimum amount of wubs in one message.
-	};
-	$self->{threshold} ||= $args->{threshold};
-	$self->{threshold} = 0.5 if $self->{threshold} >= 1 or $self->{threshold} <= 0; #sanity check lol.
-	$self->{period}    ||= $args->{period};
-	$self->{period}    = 30  if $self->{period} <= 0;	 				#same
-	$self->{max_wubs}  ||= $args->{max_wubs};
-	$self->{max_wubs}  = 20  if $self->{max_wubs} <= 0; 					#same, chap.
-	$self->{min_wubs}  ||= $args->{min_wubs};
-	$self->{min_wubs}  = 5 if $self->{min_wubs} <= 0;					#no sense in having 0 as minimum amirite
-	$self->{min_wubs}  = $self->{max_wubs} - 1 if $self->{min_wubs} > $self->{max_wubs};	#don't want minimum > maximum
-	$self->{max_wubs}  = $self->{min_wubs} + 5 if $self->{min_wubs} > $self->{max_wubs};	#same except different.
-	return bless $self, $package;
+        my $package = shift;
+        my $args = shift;
+        my $self = {
+                threshold => 0.5, #Threshold to limit unnecessary wubs.
+                period    => 30,  #A time period to rate limit wubs.
+                last_wub  => 0,
+                max_wubs =>  20,  #maximum amount of wubs in one message
+                min_wubs =>  5,   #minimum amount of wubs in one message.
+                wub_str  => "WUB", #wubstr
+        };
+        $self->{threshold} ||= $args->{threshold};
+        $self->{threshold} = 0.5 if $self->{threshold} >= 1 or $self->{threshold} <= 0; #sanity check lol.
+        $self->{period}    ||= $args->{period};
+        $self->{period}    = 30  if $self->{period} <= 0;                                       #same
+        $self->{max_wubs}  ||= $args->{max_wubs};
+        $self->{max_wubs}  = 20  if $self->{max_wubs} <= 0;                                     #same, chap.
+        $self->{min_wubs}  ||= $args->{min_wubs};
+        $self->{min_wubs}  = 5 if $self->{min_wubs} <= 0;                                       #no sense in having 0 as minimum amirite
+        $self->{min_wubs}  = $self->{max_wubs} - 1 if $self->{min_wubs} > $self->{max_wubs};    #don't want minimum > maximum
+        $self->{max_wubs}  = $self->{min_wubs} + 5 if $self->{min_wubs} > $self->{max_wubs};    #same except different.
+        $self->{wub_str}   ||= $args->{wub_str};
+        return bless $self, $package;
 }
 
-sub PCI_REGISTER {
-	my ($self, $irc) = splice @_, 0, 2;
-	
-	$irc->plugin_register( $self, 'SERVER', qw(public) );
-	return 1;
+sub S_public {
+        my($self, $irc) = splice @_, 0, 2;
+        my $channel = ${ $_[0] }->[0];
+        my $cur_time = time;
+        my $old_time = $self->{last_wub};
+        my $chance = rand;
+        my $retval = PCI_EAT_NONE;
+        if($cur_time - $old_time > $self->{period} &&
+           $chance > $self->{threshold}) {
+                        my $repetitions = (int rand($self->{max_wubs}-$self->{min_wubs})+$self->{min_wubs});
+                        my $wubstr = $self->{wub_str}x$repetitions;
+                        $irc->yield(privmsg => $channel => $wubstr);
+                        $self->{last_wub} = time;
+                        $retval = PCI_EAT_PLUGIN;
+        }
+
+        return $retval;
 }
 
-sub PCI_UNREGISTER {
-	return 1;
-}
+1;
 
-sub S_PUBLIC {
-	my($self, $irc) = splice @_, 0, 2;
-	my $channel = ${ $_[0] }->[0];
-	my $cur_time = time;
-	my $old_time = $self->{last_wub};
-	my $chance = rand;
-	my $retval = PCI_EAT_NONE;
-	if($cur_time - $old_time > $self->{period} &&
-	   $chance > $self->{threshold}) {
-			my $repetitions = (int rand($self->{max_wubs}-$self->{min_wubs})+$self->{min_wubs});
-			my $wubstr = "WUB"x$repetitions;
-			$irc->yield(privmsg => $channel => $wubstr);
-			$self->{last_wub} = time;
-			$retval = PCI_EAT_PLUGIN;
-	} 
-	
-	return $retval;
-}
-			
 
 =head1 NAME
 
@@ -65,11 +57,11 @@ POE::Component::IRC::Plugin::WubWubWub - Wubbalize your IRC bots!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.1
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.1';
 
 
 =head1 SYNOPSIS
@@ -123,6 +115,10 @@ Defaults to be 5. Should be 0 < min_wubs < max_wubs
 The maximum amount of wubs to send at any given moment when wubs are to be sent!
 Defaults to be 20. Should be max_wubs > min_wubs > 0.
 
+=item B<wub_str>
+
+The string to emit to the channel. Defaults to WUB.
+
 =back
 
 =head1 AUTHOR
